==> am_mod_lbr_0_1_0.zip: am_module_library/components/lbr/revision_edit.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$menu_section = "library";

include_once ("config/lbr.config.php");
include_once ("inc/lbr_initiate.inc.php");


if (isset($_POST['insert_revision'])) {
	
	$rec = array();
	$rec['revision_body'] = $_POST['revision_body'];
	$rec['revision_note'] = $_POST['revision_note'];
	$rec['user_id'] = $_SESSION['user_id'];
	$rec['revision_create_datetime'] = time();
	$rec['page_id'] = $_POST['page_id'];
	
	$table = $db->prefix . "_library_revision";
		
	$query = $db->GetInsertSQL($table, $rec, get_magic_quotes_gpc());
	
	$result = $db->Execute($query);
				
	if (isset($result)) {
		$revision_id = $db->Insert_ID();
	}
				
	if (isset($revision_id)) {
		// we update the current_revision_id			
		$rec = array();
		$rec['current_revision_id'] = $revision_id;
	
		$query = "
			SELECT * 
			FROM " . $db->prefix . "_library_page 
			WHERE 
			page_id=" . $_POST['page_id']
		;
		
		$result = $db->Execute($query);
		
		if (isset($result->fields)) {
			$query = $db->GetUpdateSQL($result, $rec, false, get_magic_quotes_gpc());
			$result = $db->Execute($query);
		}
	}
	
	header("Location: index.php?amn=lbr_page&page_id=" . $_POST['page_id'] . "&" . strip_tags(SID));
	exit;
}


if (!empty($output_page)) {
	$body->set('page', $output_page);
	$body->set('display', 'page_edit');
	
	// we get the requested revision
	if (isset($_REQUEST['revision_id'])) {
		$output_revision = $library->selRevision($_REQUEST['revision_id']);
		$body->set("revision", $output_revision);
		
		// get available images
		require_once ("components/core/class/File.class.php");
		$file = new File($db, $core_config['file']);
		$file->module_id = $core_config['module_id']['library'];
		$file->item_id = $output_set['set_id'];
		$file->core_config_module = $core_config['module'];
		$file->no_image = $core_config['file']['image']['thumb'][2]['no_image'];
		$file->thumbs = $core_config['file']['image']['thumb'];
		
		$images = $file->selFiles("images", "t2");
		$body->set("images", $images);
		
		$files = $file->selFiles(null);
		$body->set("files", $files);
	}
}
else {
	header("Location: index.php?amn=lbr_overview&" . strip_tags(SID));
	exit;
}


$body->set("library_config", $library_config);
$body->set("module_prefix", $core_config['module'][4]['prefix']);


?>

==> am_mod_lbr_0_2.zip: am_module_library/components/lbr/revision_edit.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$menu_section = "library";

include_once ("config/lbr.config.php");
include_once ("inc/lbr_initiate.inc.php");


if (isset($_POST['insert_revision'])) {
	
	$rec = array();
	$rec['revision_body'] = $_POST['revision_body'];
	$rec['revision_note'] = strip_tags($_POST['revision_note']);
	$rec['user_id'] = $_SESSION['user_id'];
	$rec['revision_create_datetime'] = time();
	$rec['page_id'] = $_POST['page_id'];
	
	$table = $db->prefix . "_library_revision";
		
	$query = $db->GetInsertSQL($table, $rec, get_magic_quotes_gpc());
	
	$result = $db->Execute($query);
				
	if (isset($result)) {
		$revision_id = $db->Insert_ID();
	}
				
	if (isset($revision_id)) {
		// we update the current_revision_id			
		$rec = array();
		$rec['current_revision_id'] = $revision_id;
	
		$query = "
			SELECT * 
			FROM " . $db->prefix . "_library_page 
			WHERE 
			page_id=" . $_POST['page_id']
		;
		
		$result = $db->Execute($query);
		
		if (isset($result->fields)) {
			$query = $db->GetUpdateSQL($result, $rec, false, get_magic_quotes_gpc());
			$result = $db->Execute($query);
		}
	}
	
	header("Location: index.php?amn=lbr_page&page_id=" . $_POST['page_id'] . "&" . strip_tags(SID));
	exit;
}


if (!empty($output_page)) {
	$body->set('page', $output_page);
	$body->set('display', 'page_edit');
	
	// we get the requested revision
	if (isset($_REQUEST['revision_id'])) {
		$output_revision = $library->selRevision($_REQUEST['revision_id']);
		$body->set("revision", $output_revision);
		
		// get available images
		require_once ("components/core/class/File.class.php");
		$file = new File($db, $core_config['file']);
		$file->module_id = $core_config['module_id']['library'];
		$file->item_id = $output_set['set_id'];
		$file->core_config_module = $core_config['module'];
		$file->no_image = $core_config['file']['image']['thumb'][2]['no_image'];
		$file->thumbs = $core_config['file']['image']['thumb'];
		
		$images = $file->selFiles("images", "t2");
		$body->set("images", $images);
		
		$files = $file->selFiles(null);
		$body->set("files", $files);
	}
}
else {
	header("Location: index.php?amn=lbr_overview&" . strip_tags(SID));
	exit;
}


$body->set("library_config", $library_config);
$body->set("module_prefix", $core_config['module'][4]['prefix']);


?>
